<?xml version="1.0" encoding="UTF-8"?>
<!-- Converts CINSim-0.4-files to CINSim-0.6 - tested with xsltproc -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                xmlns:ci="http://www.pdv.cs.tu-berlin.de/CINSim/schemas/CINSimPlus"
                exclude-result-prefixes="ci">
  <xsl:output method="xml" encoding="UTF-8" indent="yes" />
  
  
  <!-- 06pre2to06 1. changing namespace and schema location-->
  <xsl:template match="ci:root">
    <xsl:element name="root">
	<xsl:apply-templates select="@*"/>
	<xsl:attribute name="xmlns">http://www.pdv.cs.tu-berlin.de/CINSim/0.6/schemas/CINSimPlus</xsl:attribute>
        <xsl:attribute name="xsi:schemaLocation">http://www.pdv.cs.tu-berlin.de/CINSim/0.6/schemas/CINSimPlus etc/schemas/CINSimPlus.xsd</xsl:attribute>
	<xsl:apply-templates select="@*|node()"/>
    </xsl:element>
  </xsl:template>
  
  <!-- 04to05pre 1. remove packetsize from pareto and paretosettings -->
  <xsl:template match="ci:pareto/@packetsize|ci:paretosettings/@packetsize" />
  
  <!-- 04to05pre 2. constuniform-tag conversion -->
  <xsl:template match="ci:constuniform">
    <xsl:element name="periodic">
      <xsl:apply-templates select="node()|@*"/>
    </xsl:element>
  </xsl:template>
  
  <!-- 04to05pre 3. element periodicsettings replaces constuniformsettings-->
  <xsl:template match="ci:constuniformsettings">
    <xsl:element name="periodicsettings">
      <xsl:apply-templates select="node()|@*"/>
    </xsl:element>
  </xsl:template>
  
  <!-- 04to05pre 4. "Geometric" replaces "ConstUniform" at @traffic and @trafficType -->
  <xsl:template match="@traffic[.='ConstUniform']">
    <xsl:attribute name="traffic">Periodic</xsl:attribute>
  </xsl:template> 
  <xsl:template match="@trafficType[.='ConstUniform']">
    <xsl:attribute name="trafficType">Periodic</xsl:attribute>
  </xsl:template>
  
  <!-- 04to05pre 5. @mc_leftBorder and @mc_rightBorder replace leftBorder and @rightBorder -->
  <xsl:template match="@leftBorder">
    <xsl:attribute name="mc_leftBorder">
      <xsl:value-of select="." />
    </xsl:attribute>
  </xsl:template>
  <xsl:template match="@rightBorder">
    <xsl:attribute name="mc_rightBorder">
      <xsl:value-of select="." />
    </xsl:attribute>
  </xsl:template>

  <!-- 05preto05pre2 2. change Steady to SteadyState for simsettings/@simulationType -->
  <xsl:template match="ci:simsettings/@simulationType[.='Steady']">
    <xsl:attribute name="simulationType">SteadyState</xsl:attribute>
  </xsl:template> 
  <!-- 05preto05pre2 2. change Transient to Terminating for simsettings/@simulationType -->
  <xsl:template match="ci:simsettings/@simulationType[.='Transient']">
    <xsl:attribute name="simulationType">Terminating</xsl:attribute>
  </xsl:template> 
  
  <!-- 05preto05pre2 3. analysisStart replaces transientStart -->
  <xsl:template match="ci:simsettings/@transientStart">
    <xsl:attribute name="analysisStart">
      <xsl:value-of select="." />
    </xsl:attribute>
  </xsl:template>
  <!-- 05preto05pre2 3. analysisLength has to be calculated from transientEnd -->
  <xsl:template match="ci:simsettings/@transientEnd">
    <xsl:attribute name="analysisLength">
      <xsl:value-of select=". - ./../@transientStart + 1" />
    </xsl:attribute>
  </xsl:template>
  
  <!-- 05preto05pre2 4. element analyser replaces analyzer 
       05preto05pre2 6. analyser (old analyzer) needs attribute @index; initial set to 0
       GUI will fix this. -->
  <xsl:template match="ci:analyzer">
    <xsl:element name="analyser">
      <xsl:attribute name="index">-</xsl:attribute>
      <xsl:apply-templates select="node()|@*"/>
    </xsl:element>
  </xsl:template>
  
  <!-- 05preto05pre2 5. removing attributes @observationType and @packetPriority from
       element analyzer -->
  <xsl:template match="ci:analyzer/@observationType|ci:analyzer/@packetPriority" />
  
  <!-- 05preto05pre2 7. measurevar/@description replaces measurevar/@name -->
  <xsl:template match="ci:measurevar/@name">
    <xsl:attribute name="description">
      <xsl:value-of select="." />
    </xsl:attribute>
  </xsl:template>
  
  <!-- 05preto05pre2 8. sourcebuffer[settings] replaces packetgen[settings] -->
  <xsl:template match="ci:packetgen">
    <xsl:element name="sourcebuffer">
      <xsl:apply-templates select="node()|@*"/>
    </xsl:element>
  </xsl:template>
  <xsl:template match="ci:packetgensettings">
    <xsl:element name="sourcebuffersettings">
      <xsl:apply-templates select="node()|@*"/>
    </xsl:element>
  </xsl:template>
  
  <!-- 05preto05pre2 9. geometric[settings] replaces constrandom[settings] -->
  <xsl:template match="ci:constrandom">
    <xsl:element name="geometric">
      <xsl:apply-templates select="node()|@*"/>
    </xsl:element>
  </xsl:template>
  <xsl:template match="ci:constrandomsettings">
    <xsl:element name="geometricsettings">
      <xsl:apply-templates select="node()|@*"/>
    </xsl:element>
  </xsl:template>
  
  
  <!-- 05preto05pre2 10. "Geometric" replaces "ConstRandom" at constrandom[settings]/@traffic  -->
  <xsl:template match="@traffic[.='ConstRandom']">
    <xsl:attribute name="traffic">Geometric</xsl:attribute>
  </xsl:template> 
  <xsl:template match="@trafficType[.='ConstRandom']">
    <xsl:attribute name="trafficType">Geometric</xsl:attribute>
  </xsl:template>
  
  <!-- 05preto05pre2 11. removes attribute maxLoad from constrandom[settings] --> 
  <xsl:template match="ci:constrandomsettings/@maxLoad|ci:constrandom/@maxLoad" />
  
  <!-- 05preto05pre2 12. @burstLoad and @gapLoad replaces @burstRate and @gapRate
       05preto05pre2 13. all @load are given as a probability (div 100)-->
  <xsl:template match="@burstRate[string(number(.))!='NaN']">
    <xsl:attribute name="burstLoad">
      <xsl:value-of select=". div 100" />
    </xsl:attribute>
  </xsl:template>
  <xsl:template match="@gapRate[string(number(.))!='NaN']">
    <xsl:attribute name="gapLoad">
      <xsl:value-of select=". div 100" />
    </xsl:attribute>
  </xsl:template>
  <xsl:template match="@load[string(number(.))!='NaN']">
    <xsl:attribute name="load">
      <xsl:value-of select=". div 100" />
    </xsl:attribute>
  </xsl:template>
  
  <!-- 05preto05pre2 14. remove "NoObservation" of measurevar/@observationType 
       setting default-value "Delay" -->
  <xsl:template match="ci:measurevar/@observationType[.='NoObservation']">
    <xsl:attribute name="observationType">Delay</xsl:attribute>
  </xsl:template>
  
  <!-- 05preto05pre2 15. non-negative values are not allowed for @index and @route setting to default -->
  <xsl:template match="@index[.&lt;0]">
    <xsl:attribute name="index">-</xsl:attribute> 
  </xsl:template>
  <xsl:template match="@route[.&lt;0]">
    <xsl:attribute name="route">-</xsl:attribute> 
  </xsl:template>
  
  
  <!-- copy unmodified stuff -->
  <xsl:template match="node()">
    <xsl:element name="{name()}">
      <xsl:apply-templates select="@*|node()"/>
    </xsl:element>
  </xsl:template>
  <xsl:template match="@*|text()|comment()|processing-instruction()">
    <xsl:copy/>
  </xsl:template> 
</xsl:stylesheet>
